RIPE abuse contacts resolving through DNS TXT queries

Reference: https://abusix.com/contactdb.html

This bot can optionally use the python module *querycontacts* by abusix itself:
https://pypi.org/project/querycontacts/

It is only available for Python 2.7.
Install via:

```bash
pip install -U querycontacts
```

If the package is not installed, our own routines are used.
